@@ -1,11 +1,14 @@
 from mitama.app import BaseMetadata
-from mitama.db import get_app_engine, Database as BaseDatabase
+from mitama.db import Database as BaseDatabase
+from mitama.db import get_app_engine
+
 
 class Metadata(BaseMetadata):
     pass
 
+
 class Database(BaseDatabase):
-    def __init__(self, engine = None):
+    def __init__(self, engine=None):
         super().__init__()
         meta = Metadata()
         if self.engine == None:
@@ -14,6 +17,7 @@ class Database(BaseDatabase):
             else:
                 self.set_engine(engine)
 
+
 def init_app(name):
     meta = Metadata()
     meta.name = name
