@@ -1,4 +1,3 @@
 from . import views
 
-urls = [
-]
+urls = []
